@@ -1,5 +1,5 @@
 package OpenTracing::WrapScope;
-our $VERSION = 'v0.106.1_1';
+our $VERSION = 'v0.106.2';
 use strict;
 use warnings;
 use warnings::register;
@@ -32,7 +32,7 @@ no warnings 'redefine';
 my %subs_to_install;
 END {
     foreach my $sub (keys %subs_to_install) {
-        warnings::warn "OpenTracing::WrapScope couldn't find sub: $_";
+        warnings::warn "OpenTracing::WrapScope couldn't find sub: $sub";
     }
 }
 
